@@ -440,7 +440,7 @@ start_shell <- function(master,
   }
 
   # batch connections only use the shell to submit an application, not to connect.
-  if (identical(batch, TRUE)) {
+  if (identical(isBatch, TRUE)) {
     return(NULL)
   }
 
