@@ -288,7 +288,7 @@ path_program <- function(program, fmt = NULL) {
 }
 
 infer_active_package_name <- function() {
-  root <- rprojroot::find_package_root_file()
+  root <- package_root()
   dcf <- read.dcf(file.path(root, "DESCRIPTION"), all = TRUE)
   dcf$Package
 }
@@ -481,11 +481,21 @@ simulate_vars_spark <- function(x, drop_groups = FALSE) {
     tibble::as_tibble()
 }
 
-simulate_vars.tbl_spark <- function(x, drop_groups = FALSE) {
-  simulate_vars_spark(x, drop_groups)
+#' @importFrom tidyselect tidyselect_data_proxy tidyselect_data_has_predicates
+#' @export
+tidyselect_data_proxy.tbl_spark <- function(x) {
+  simulate_vars_spark(x, FALSE)
 }
 
-simulate_vars_is_typed.tbl_spark <- function(x) TRUE
+#' @export
+tidyselect_data_has_predicates.tbl_spark <- function(x) {
+  supported <- unlist(options("sparklyr.support.predicates"))
+  out <- TRUE
+  if(!is.null(supported)) {
+    out <- supported
+  }
+  out
+}
 
 # wrapper for download.file()
 download_file <- function(...) {
@@ -522,7 +532,7 @@ infer_required_r_packages <- function(fn) {
   rlang::fn_body(fn) %>%
     globals::walkAST(
       call = function(x) {
-        cfn <- rlang::call_fn(x)
+        cfn <- rlang::eval_bare(x[[1]])
 
         for (mfn in list(base::library,
                          base::require,
@@ -559,3 +569,88 @@ infer_required_r_packages <- function(fn) {
 os_is_windows <- function() {
   .Platform$OS.type == "windows"
 }
+
+cast_string <- function(x) {
+  vctrs::vec_check_size(x, 1, arg = rlang::caller_arg(x), call = rlang::caller_env())
+  vctrs::vec_cast(x, character())
+}
+
+cast_scalar_logical <- function(x) {
+  vctrs::vec_check_size(x, 1, arg = rlang::caller_arg(x), call = rlang::caller_env())
+  vctrs::vec_cast(x, logical())
+}
+
+cast_scalar_double <- function(x) {
+  vctrs::vec_check_size(x, 1, arg = rlang::caller_arg(x), call = rlang::caller_env())
+  vctrs::vec_cast(x, numeric())
+}
+
+cast_scalar_integer <- function(x) {
+  vctrs::vec_check_size(x, 1, arg = rlang::caller_arg(x), call = rlang::caller_env())
+  vctrs::vec_cast(x, integer())
+}
+
+cast_nullable_string <- function(x) {
+  if (is.null(x)) {
+    return(NULL)
+  }
+
+  cast_string(x)
+}
+
+cast_nullable_scalar_double <- function(x) {
+  if (is.null(x)) {
+    return(NULL)
+  }
+
+  cast_scalar_double(x)
+}
+
+cast_nullable_scalar_integer <- function(x) {
+  if (is.null(x)) {
+    return(NULL)
+  }
+
+  cast_scalar_integer(x)
+}
+
+
+cast_double <- function(x) {
+  vctrs::vec_cast(x, numeric())
+}
+
+cast_integer <- function(x) {
+  vctrs::vec_cast(x, integer())
+}
+
+cast_list <- function(x, ptype, allow_null = FALSE) {
+  if (is.null(x)) {
+    if (allow_null) {
+      return(NULL)
+    } else {
+      rlang::abort("{.arg x} must not be `NULL`.")
+    }
+  }
+
+  if (is.list(x)) {
+    x <- vctrs::list_unchop(x)
+  }
+  x <- vctrs::vec_cast(x, to = ptype)
+  vctrs::vec_chop(x)
+}
+
+cast_string_list <- function(x, allow_null = FALSE) {
+  cast_list(x, character(), allow_null = allow_null)
+}
+
+cast_integer_list <- function(x, allow_null = FALSE) {
+  cast_list(x, integer(), allow_null = allow_null)
+}
+
+cast_double_list <- function(x, allow_null = FALSE) {
+  cast_list(x, numeric(), allow_null = allow_null)
+}
+
+cast_choice <- function(x, choices, error_arg = rlang::caller_arg(x), error_call = rlang::caller_env()) {
+  rlang::arg_match(x, choices, error_arg = error_arg, error_call = error_call)
+}
